Internal QUICHE change

PiperOrigin-RevId: 252503217
Change-Id: Idb990fa3b17ff75f67e9c366463a7d4419d05849
diff --git a/quic/tools/quic_toy_client.h b/quic/tools/quic_toy_client.h
index e832ac7..1a20122 100644
--- a/quic/tools/quic_toy_client.h
+++ b/quic/tools/quic_toy_client.h
@@ -18,10 +18,12 @@
    public:
     virtual ~ClientFactory() = default;
 
     // Creates a new client configured to connect to |host:port| supporting
     // |versions|, and using |verifier| to verify proofs.
     virtual std::unique_ptr<QuicSpdyClientBase> CreateClient(
-        std::string host,
+        std::string host_for_handshake,
+        std::string host_for_lookup,
         uint16_t port,
         ParsedQuicVersionVector versions,
         std::unique_ptr<ProofVerifier> verifier) = 0;
@@ -18,10 +18,12 @@
     virtual ~ClientFactory() = default;
 
-    // Creates a new client configured to connect to |host:port| supporting
-    // |versions|, and using |verifier| to verify proofs.
+    // Creates a new client configured to connect to |host_for_lookup:port|
+    // supporting |versions|, using |host_for_handshake| for handshake and
+    // |verifier| to verify proofs.
     virtual std::unique_ptr<QuicSpdyClientBase> CreateClient(